# Generated by Django migration system

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_scion', '0003_fix_cores_field'),
    ]

    operations = [
        migrations.AddField(
            model_name='scionlinkassignment',
            name='core',
            field=models.CharField(default='', help_text='Core node for this assignment', max_length=255),
            preserve_default=False,
        ),
    ]
